// **********************************************************************
//
// Copyright (c) 2003-2010 ZeroC, Inc. All rights reserved.
//
// This copy of Ice is licensed to you under the terms described in the
// ICE_LICENSE file included in this distribution.
//
// **********************************************************************

// Ice version 3.4.1

package Freeze;

// <auto-generated>
//
// Generated from file `Evictor.ice'
//
// Warning: do not edit this file.
//
// </auto-generated>


/**
 * An automatic Ice object persistence manager, based on the
 * evictor pattern. The evictor is a servant locator implementation
 * that stores the persistent state of its objects in a database. Any
 * number of objects can be registered with an evictor, but only a
 * configurable number of servants are active at a time.  These active
 * servants reside in a queue; the least recently used servant in the
 * queue is the first to be evicted when a new servant is activated.
 * 
 * 
 * @see ServantInitializer
 * 
 **/
public interface Evictor extends Ice.ServantLocator
{
    /**
     * Set the size of the evictor's servant queue. This is the
     * maximum number of servants the evictor keeps active. Requests
     * to set the queue size to a value smaller than zero are ignored.
     * 
     * @param sz The size of the servant queue. If the evictor
     * currently holds more than <tt>sz</tt> servants in its queue, it evicts
     * enough servants to match the new size. Note that this operation
     * can block if the new queue size is smaller than the current
     * number of servants that are servicing requests. In this case,
     * the operation waits until a sufficient number of servants
     * complete their requests.
     * 
     * 
     * @throws EvictorDeactivatedException Raised if a the evictor has
     * been deactivated.
     * 
     * @see #getSize
     * 
     **/
    void setSize(int sz);

    /**
     * Get the size of the evictor's servant queue.
     * 
     * @return The size of the servant queue.
     * 
     * @throws EvictorDeactivatedException Raised if a the evictor has
     * been deactivated.
     * 
     * @see #setSize
     * 
     **/
    int getSize();

    /**
     * Add a servant to this evictor. The state of the servant passed to 
     * this operation will be saved in the evictor's persistent store.
     * 
     * @param servant The servant to add.
     * 
     * @param id The identity of the Ice object that is implemented by 
     * the servant.
     * 
     * @return A proxy that matches the given identity and this evictor's
     * object adapter.
     * 
     * @throws Ice.AlreadyRegisteredException Raised if the evictor already has
     * an object with this identity.
     * 
     * @throws DatabaseException Raised if a database failure occurred.
     * 
     * @throws EvictorDeactivatedException Raised if the evictor has
     * been deactivated.
     * 
     * @see #addFacet
     * @see #remove
     * @see #removeFacet
     * 
     **/
    Ice.ObjectPrx add(Ice.Object servant, Ice.Identity id);

    /**
     * Like {@link #add}, but with a facet. Calling <tt>add(servant, id)</tt>
     * is equivalent to calling {@link #addFacet} with an empty
     * facet.
     * 
     * @param servant The servant to add.
     * 
     * @param id The identity of the Ice object that is implemented by 
     * the servant.
     * 
     * @param facet The facet. An empty facet means the default
     * facet.
     * 
     * @return A proxy that matches the given identity and this evictor's
     * object adapter.
     * 
     * @throws Ice.AlreadyRegisteredException Raised if the evictor already has
     * an object with this identity.
     * 
     * @throws DatabaseException Raised if a database failure occurred.
     * 
     * @throws EvictorDeactivatedException Raised if the evictor has
     * been deactivated.
     * 
     * @see #add
     * @see #remove
     * @see #removeFacet
     * 
     **/
    Ice.ObjectPrx addFacet(Ice.Object servant, Ice.Identity id, String facet);

    /**
     * Permanently destroy an Ice object.
     * 
     * @param id The identity of the Ice object.
     * 
     * @return The removed servant.
     * 
     * @throws Ice.NotRegisteredException Raised if this identity was not 
     * registered with the evictor.
     * 
     * @throws DatabaseException Raised if a database failure occurred.
     * 
     * @throws EvictorDeactivatedException Raised if the evictor has
     * been deactivated.
     * 
     * @see #add
     * @see #removeFacet
     * 
     **/
    Ice.Object remove(Ice.Identity id);

    /**
     * Like {@link #remove}, but with a facet. Calling <tt>remove(id)</tt> 
     * is equivalent to calling {@link #removeFacet} with an empty facet.
     * 
     * @param id The identity of the Ice object.
     * 
     * @param facet The facet. An empty facet means the default
     * facet.
     * 
     * @return The removed servant.
     * 
     * @throws Ice.NotRegisteredException Raised if this identity was not 
     * registered with the evictor.
     * 
     * @throws DatabaseException Raised if a database failure occurred.
     * 
     * @throws EvictorDeactivatedException Raised if the evictor has
     * been deactivated.
     * 
     * 
     * @see #remove
     * @see #addFacet
     * 
     **/
    Ice.Object removeFacet(Ice.Identity id, String facet);

    /**
     * Returns true if the given identity is managed by the evictor
     * with the default facet.
     * 
     * @return true if the identity is managed by the evictor, false
     * otherwise.
     * 
     * @throws DatabaseException Raised if a database failure occurred.
     * 
     * @throws EvictorDeactivatedException Raised if a the evictor has
     * been deactivated.
     * 
     **/
    boolean hasObject(Ice.Identity id);

    /**
     * Like {@link #hasObject}, but with a facet. Calling <tt>hasObject(id)</tt>
     * is equivalent to calling {@link #hasFacet] with an empty
     * facet.
     * 
     * @return true if the identity is managed by the evictor for the
     * given facet, false otherwise.
     * 
     * @throws DatabaseException Raised if a database failure occurred.
     * 
     * @throws EvictorDeactivatedException Raised if a the evictor has
     * been deactivated.
     * 
     **/
    boolean hasFacet(Ice.Identity id, String facet);

    /**
     * Get an iterator for the identities managed by the evictor.
     * 
     * @param facet The facet. An empty facet means the default
     * facet.
     * 
     * @param batchSize Internally, the Iterator retrieves the
     * identities in batches of size batchSize. Selecting a small batchSize
     * can have an adverse effect on performance.
     * 
     * @return A new iterator.
     * 
     * @throws EvictorDeactivatedException Raised if a the evictor has
     * been deactivated.
     * 
     **/
    EvictorIterator getIterator(String facet, int batchSize);
}
